@@ -6,7 +6,7 @@ from os import environ
 from .base import dumb_pipe, using_path, is_pipeline, \
   RC_ENV_VAR, RC_OK
 
-from play_sounds import play_file, play_after, DEFAULT_SOUND
+from play_sounds import play_after, DEFAULT_SOUND
 import click
 
 
